@@ -34,10 +34,12 @@ quick_access_set = {
     "_skip_ellipsis",
     "_update_and_follow",
     "_update_excluded_with_related_not_required",
+    "_verify_model_can_be_initialized",
     "copy",
     "delete",
     "dict",
     "extract_related_names",
+    "extract_through_names",
     "update_from_dict",
     "get_column_alias",
     "get_column_name_from_alias",
